@@ -3,7 +3,7 @@ package Prima::sys::AnyEvent;
 use strict;
 use warnings;
 use AnyEvent;
-use Prima;
+use Prima qw(Application);
 
 sub io
 {
@@ -61,10 +61,6 @@ sub poll { $::application->yield }
 
 push @AnyEvent::REGISTRY, ["Prima", __PACKAGE__ ];
 
-1;
-
-=pod
-
 =head1 NAME
 
 Prima::sys::AnyEvent - AnyEvent bridge
@@ -75,7 +71,7 @@ Prima::sys::AnyEvent - AnyEvent bridge
    use AnyEvent;
 
    my $ev = AnyEvent->timer(after => 1, cb => sub { print "waited 1 second!\n" });
-   Prima->run;
+   run Prima;
 
 =head1 DESCRIPTION
 
@@ -95,3 +91,5 @@ Dmitry Karasik
 F<examples/socket_anyevent.pl>
 
 =cut
+
+1;
