@@ -821,15 +821,11 @@ my_GetUserPreferredUILanguages(
 #define CONSOLE_READ_NOWAIT     0x0002
 #endif
 
-BOOL
-WINAPI
-ReadConsoleInputExW(
-    _In_ HANDLE hConsoleInput,
-    _Out_writes_(nLength) PINPUT_RECORD lpBuffer,
-    _In_ DWORD nLength,
-    _Out_ LPDWORD lpNumberOfEventsRead,
-    _In_ USHORT wFlags);
-
+Bool
+read_console_input(
+	WINHANDLE hConsoleInput, PINPUT_RECORD lpBuffer, DWORD nLength,
+	LPDWORD lpNumberOfEventsRead, USHORT wFlags
+);
 
 #ifdef __cplusplus
 }
