@@ -132,14 +132,14 @@ prima_wm_net_state_read_maximization( XWindow window, Atom property)
 		else if ( prop[i] == guts. atoms[ AI_NET_WM_STATE_MAXIMIZED_HORZ]) {
 			if ( guts. net_wm_maximize_HORZ_vs_HORIZ == 0) {
 				guts. net_wm_maximize_HORZ_vs_HORIZ = AI_NET_WM_STATE_MAXIMIZED_HORZ;
-				Mdebug("wm: kde-3 style detected");
+				Mdebug("wm: kde-3 style detected\n");
 			}
 			horiz = 1;
 		}
 		else if ( prop[i] == guts. atoms[ AI_NET_WM_STATE_MAXIMIZED_HORIZ]) {
 			if ( guts. net_wm_maximize_HORZ_vs_HORIZ == 0) {
 				guts. net_wm_maximize_HORZ_vs_HORIZ = AI_NET_WM_STATE_MAXIMIZED_HORIZ;
-				Mdebug("wm: kde-2 style detected");
+				Mdebug("wm: kde-2 style detected\n");
 			}
 			horiz = 1;
 		}
@@ -159,7 +159,7 @@ net_supports_maximization(void)
 	has_max = prima_wm_net_state_read_maximization( guts. root, NET_SUPPORTED);
 	if ( has_max != guts. net_wm_maximization) {
 		guts. net_wm_maximization = has_max;
-		Mdebug( has_max ? "wm: supports maximization" : "win: WM quits supporting maximization");
+		Mdebug( has_max ? "wm: supports maximization\n" : "win: WM quits supporting maximization\n");
 	}
 	return has_max;
 }
@@ -182,7 +182,7 @@ net_supports_fullscreen(void)
 		}
 	if ( ok != guts. net_wm_fullscreen ) {
 		guts. net_wm_fullscreen = ok;
-		Mdebug( ok ? "wm: supports fullscreen" : "wm: quits supporting fullscreen");
+		Mdebug( ok ? "wm: supports fullscreen\n" : "wm: quits supporting fullscreen\n");
 	}
 
 	return ok;
@@ -576,7 +576,7 @@ create_window( Handle self, XWindow parent, unsigned long valuemask, XSetWindowA
 }
 
 Bool
-apc_window_create( Handle self, Handle owner, int border_icons,
+apc_window_create( Handle self, Handle owner, Bool sync_paint, int border_icons,
 	int border_style, Bool task_list, int window_state,
 	int on_top, Bool use_origin, Bool use_size, Bool layered
 ) {
@@ -655,6 +655,7 @@ apc_window_create( Handle self, Handle owner, int border_icons,
 	XX-> flags.iconic      = ( window_state == wsMinimized) ? 1 : 0;
 	XX-> borderIcons       = border_icons;
 	XX-> flags.clip_owner  = false;
+	XX-> flags.sync_paint  = sync_paint;
 	XX-> flags.task_listed = 1;
 	XX-> flags.layered     = XX-> flags. layered_requested = !!layered;
 	XX-> flags. sizeable   = border_style == bsSizeable;
@@ -689,7 +690,7 @@ recreate_window_with_emulated_fullscreen( Handle self, int window_state)
 {
 	DEFXX;
 	return apc_window_create( self,
-		PComponent(self)->owner, XX->borderIcons,
+	 	PComponent(self)->owner, XX->flags.sync_paint, XX->borderIcons,
 	 	XX->flags.sizeable ? bsSizeable : bsDialog, XX->flags.task_listed, window_state,
 	 	XX->flags.on_top, false, false, XX->flags.layered);
 }
@@ -1609,11 +1610,8 @@ apc_window_execute( Handle self, Handle insert_before)
 	while ( prima_one_loop_round( WAIT_IF_NONE, true) && XX-> flags.modal)
 		;
 
-	if ( X_WINDOW ) {
-		if ( toplevel) XSetTransientForHint( DISP, X_WINDOW, None);
-		NETWM_SET_MODAL( X_WINDOW, XX-> flags.modal);
-	}
-
+	if ( toplevel) XSetTransientForHint( DISP, X_WINDOW, None);
+	if ( X_WINDOW) NETWM_SET_MODAL( X_WINDOW, XX-> flags.modal);
 	unprotect_object( self);
 	return true;
 }
