@@ -162,10 +162,10 @@ icon2argb( PIcon i, uint32_t * argb_bits, Bool invert, unsigned int alpha)
 		register Byte *rgb_ptr = rgb_bits, *a_ptr = a_bits, *argb_ptr = (Byte*) argb_bits;
 		register int x = i->w;
 		for ( ; x > 0; x--) {
-			*argb_ptr++ = *rgb_ptr++ * alpha / 255;
-			*argb_ptr++ = *rgb_ptr++ * alpha / 255;
-			*argb_ptr++ = *rgb_ptr++ * alpha / 255;
-			*argb_ptr++ = *a_ptr++   * alpha / 255;
+			*argb_ptr++ = *rgb_ptr++;
+			*argb_ptr++ = *rgb_ptr++;
+			*argb_ptr++ = *rgb_ptr++;
+			*argb_ptr++ = *a_ptr++ * alpha / 255;
 		}
 	}
 
@@ -724,7 +724,7 @@ image_destroy_cache( Handle self)
 	sys s. image. cache. cache_type = BM_NONE;
 }
 
-Bool
+void
 image_query_bits( Handle self, Bool forceNewImage)
 {
 	PImage i = ( PImage) self;
@@ -737,13 +737,13 @@ image_query_bits( Handle self, Bool forceNewImage)
 	if ( forceNewImage) {
 		ops = sys ps;
 		if ( !ops) {
-			if ( !( sys ps = dc_alloc())) return false;
+			if ( !( sys ps = dc_alloc())) return;
 		}
 	}
 
 	if ( !GetObject( sys bm, sizeof( BITMAP), ( LPSTR) &bitmap)) {
 		apiErr;
-		return false;
+		return;
 		// if GetObject fails to get even BITMAP, there will be no good in farther run for sure.
 	}
 
@@ -785,8 +785,6 @@ image_query_bits( Handle self, Bool forceNewImage)
 		}
 		sys ps = ops;
 	}
-
-	return true;
 }
 
 static Handle ctx_rop2R4[] = {
@@ -1106,7 +1104,7 @@ img_put_argb_on_bitmap( Handle self, Handle image, PutImageRequest * req)
 {
 	if ( !img_put_and_mask( sys ps, image, req))
 		return false;
-	req-> rop = (req->rop == ropBlend) ? ropOrPut : ropCopyPut;
+	req-> rop = (req->rop == ropSrcCopy) ? ropCopyPut : ropOrPut;
 	return img_put_image_on_bitmap( self, image, req );
 }
 
@@ -1203,8 +1201,10 @@ img_put_argb_on_pixmap( Handle self, Handle image, PutImageRequest * req)
 	HDC src;
 	HBITMAP old;
 
-	if ( req-> rop == ropCopyPut )
+	if ( req-> rop == ropSrcCopy ) {
+		req-> rop = ropCopyPut;
 		return img_put_image_on_pixmap( self, image, req);
+	}
 
 	image_fill_bitmap_cache( image, BM_LAYERED, self );
 	if ( dsys(image) bm == NULL)
@@ -1222,9 +1222,11 @@ img_put_argb_on_pixmap( Handle self, Handle image, PutImageRequest * req)
 static Bool
 img_put_layered_on_pixmap( Handle self, Handle image, PutImageRequest * req)
 {
-	return (req-> rop == ropCopyPut) ?
-		img_put_pixmap_on_pixmap( self, image, req) :
-		img_put_alpha_blend( sys ps, dsys(image)ps, req);
+	if ( req-> rop == ropSrcCopy ) {
+		req-> rop = ropCopyPut;
+		return img_put_pixmap_on_pixmap( self, image, req);
+	} else
+		return img_put_alpha_blend( sys ps, dsys(image)ps, req);
 }
 
 /* layered */
@@ -1253,7 +1255,8 @@ img_put_argb_on_layered( Handle self, Handle image, PutImageRequest * req)
 
 	src = CreateCompatibleDC(sys ps);
 	old = SelectObject(src, dsys (image) bm);
-	if ( req-> rop == ropCopyPut ) {
+	if ( req-> rop == ropSrcCopy ) {
+		req-> rop = ropCopyPut;
 		img_draw_black_rect( self, req );
 		ok = img_put_stretch_blt( sys ps, src, req);
 	} else
@@ -1322,7 +1325,8 @@ img_put_a8_on_layered( Handle self, Handle image, PutImageRequest * req)
 static Bool
 img_put_layered_on_layered( Handle self, Handle image, PutImageRequest * req)
 {
-	if ( req-> rop == ropCopyPut ) {
+	if ( req-> rop == ropSrcCopy ) {
+		req-> rop = ropCopyPut;
 		img_draw_black_rect( self, req );
 		return img_put_stretch_blt( sys ps, dsys(image)ps, req);
 	} else
@@ -1372,7 +1376,6 @@ apc_gp_stretch_image( Handle self, Handle image,
 	dobjCheck(image) false;
 
 	select_world_transform(self, use_matrix);
-	select_world_transform(image, false);
 
 	if ( src_h < 0) {
 		src_h = -src_h;
@@ -1418,43 +1421,6 @@ apc_gp_stretch_image( Handle self, Handle image,
 	req. dst_h = dst_h;
 	req. rop   = rop;
 
-	if (use_matrix) {
-		Matrix *m0 = &var current_state.matrix;
-		Matrix m1  = {
-			(*m0)[0], -((*m0)[1]),
-			-((*m0)[2]), (*m0)[3],
-			0, 0
-		};
-		XFORM xf  = {
-			(*m0)[0], -((*m0)[1]),
-			-((*m0)[2]), (*m0)[3],
-			dst_x - sys transform2.x,
-			sys last_size.y - dst_y - 1 - sys transform2.y
-		};
-		NPoint
-			delta = {-0.5, 0.5},
-			pixel[2] = {{1.0,0.0},{0.0,1.0}},
-			pixel_size;
-
-		/* win32 aperture is upper (0,0), while we need lower (0,dst_h-1).
-		Also, experiments show that the target pixel aperture is not at (0,0) but at (0.5,0.5),
-		in the center of the first target pixel -
-		determine the size of that pixel to translate it back after eventual scaling */
-		prima_matrix_apply2( m1, pixel, pixel, 2);
-		pixel_size.x = sqrt( pixel[0].x * pixel[0].x + pixel[0].y * pixel[0].y);
-		pixel_size.y = sqrt( pixel[1].x * pixel[1].x + pixel[1].y * pixel[1].y);
-		if ( pixel_size.x > 0.0 ) delta.x /= pixel_size.x;
-		if ( pixel_size.y > 0.0 ) delta.y /= pixel_size.y;
-		delta.y -= (double) dst_h;
-		prima_matrix_apply( m1, &delta.x, &delta.y);
-		xf.eDx += delta.x;
-		xf.eDy += delta.y;
-		SetWorldTransform( sys ps, &xf );
-		apt_clear( aptCachedWorldTransform );
-		req.dst_x = 0;
-		req.dst_y = 0;
-	}
-
 	if ( dsys( image) options. aptDeviceBitmap ) {
 		PDeviceBitmap p = (PDeviceBitmap) image;
 		switch (p->type) {
@@ -1489,9 +1455,9 @@ apc_gp_stretch_image( Handle self, Handle image,
 	}
 
 	if (( is_apt(aptDeviceBitmap) && ((PDeviceBitmap)self)->type == dbtBitmap) ||
-		( is_apt(aptImage)        && ((PImage)self)-> type == imBW )) {
+		( is_apt(aptImage)        && ((PImage)self)-> type == imBW ))
 		dst = img_put_on_bitmap;
-	} else if ( is_apt(aptLayered))
+	else if ( is_apt(aptLayered))
 		dst = img_put_on_layered;
 	else if (( is_apt(aptDeviceBitmap) && ((PDeviceBitmap)self)->type == dbtPixmap) ||
 		(is_apt(aptImage)        && ((PImage)self)-> type != imBW ))
@@ -1511,11 +1477,7 @@ apc_gp_stretch_image( Handle self, Handle image,
 		rop = ropCopyPut;
 	}
 
-	if ( src == SRC_LAYERED || src == SRC_ARGB ) {
-		if ( rop != ropCopyPut && rop != ropBlend ) return false;
-	} else {
-		if ( rop > ropWhiteness ) return false;
-	}
+	if ( rop > ropNoOper ) return false;
 
 	if ( dst[src] == NULL ) {
 		warn("not implemented");
@@ -1993,43 +1955,6 @@ apc_dbm_get_handle( Handle self)
 	return ( ApiHandle) sys ps;
 }
 
-Byte
-apc_gp_get_mask_pixel( Handle self, int x, int y)
-{
-	uint32_t *p;
-	PDrawable d = ( PDrawable ) self;
-	objCheck 0;
-
-	if ( !((is_apt(aptIcon) || is_apt(aptDeviceBitmap)) && is_apt(aptLayered)))
-		return false;
-	select_world_transform(self, false);
-	SHIFT_XY(x,y);
-	if ( x < 0 || x >= d-> w || y < 0 || y > d-> h) return 0;
-
-	p = sys s. image. argb_bits + d-> h * y + x;
-	return (*p) >> 24;
-}
-
-Bool
-apc_gp_set_mask_pixel( Handle self, int x, int y, Byte pixel)
-{
-	uint32_t *p;
-	PDrawable d = ( PDrawable ) self;
-	objCheck false;
-
-	if ( !((is_apt(aptIcon) || is_apt(aptDeviceBitmap)) && is_apt(aptLayered)))
-		return false;
-	select_world_transform(self, false);
-	SHIFT_XY(x,y);
-	if ( x < 0 || x >= d-> w || y < 0 || y > d-> h) return false;
-
-	p = sys s. image. argb_bits + d-> h * y + x;
-	*p &= 0x00ffffff;
-	*p |= ((uint32_t) pixel) << 24;
-
-	return true;
-}
-
 
 #ifdef __cplusplus
 }
